#
# spec file for package dnf-plugins-core
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2021 Neal Gompa <ngompa13@gmail.com>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!dnf_lowest_compatible: %global dnf_lowest_compatible 4.11.0}
%global dnf_plugins_extra 2.0.0
%global hawkey_version 0.64.0

%if 0%{?is_opensuse}
# Copr targets are available for openSUSE Leap 15.0 and newer
%bcond_without copr_plugin
%else
# Copr plugin is not supported for this target
%bcond_with copr_plugin
%endif

# YUM v3 has been removed from openSUSE Tumbleweed as of 20191119
%if 0%{?sle_version} && 0%{?sle_version} < 160000
%bcond_with as_yum
%else
%bcond_without as_yum
%endif

%if %{with as_yum}
%global yum_utils_subpackage_name yum-utils
%else
%global yum_utils_subpackage_name dnf-utils
%endif

# Deal with SLE Backports issues
%if 0%{?sle_version} && 0%{?is_backports}
%bcond_without deconflict
%global deconflict_prefix dnfutils-
%else
%bcond_with deconflict
%global deconflict_prefix %{nil}
%endif

%bcond_without tests

#global prerel rc1

Name:           dnf-plugins-core
Version:        4.3.1
Release:        2.2
Summary:        Core Plugins for DNF
License:        GPL-2.0-or-later
Group:          System/Packages
URL:            https://github.com/rpm-software-management/dnf-plugins-core
Source0:        %{url}/archive/%{version}/%{name}-%{version}.tar.gz

BuildArch:      noarch

BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gettext
Requires:       python3-dnf-plugins-core = %{version}-%{release}
Recommends:     %{name}-lang >= %{version}

Provides:       dnf-command(builddep)
Provides:       dnf-command(config-manager)
%if %{with copr_plugin}
Provides:       dnf-command(copr)
%endif
Provides:       dnf-command(builddep)
Provides:       dnf-command(changelog)
Provides:       dnf-command(config-manager)
Provides:       dnf-command(copr)
Provides:       dnf-command(debug-dump)
Provides:       dnf-command(debug-restore)
Provides:       dnf-command(debuginfo-install)
Provides:       dnf-command(download)
Provides:       dnf-command(groups-manager)
Provides:       dnf-command(repoclosure)
Provides:       dnf-command(repodiff)
Provides:       dnf-command(repograph)
Provides:       dnf-command(repomanage)
Provides:       dnf-command(reposync)

# Plugins shift from extras to core
Provides:       dnf-plugins-extras-debug = %{version}-%{release}
Provides:       dnf-plugins-extras-repoclosure = %{version}-%{release}
Provides:       dnf-plugins-extras-repograph = %{version}-%{release}
Provides:       dnf-plugins-extras-repomanage = %{version}-%{release}
# Generic package name Provides
Provides:       dnf-plugin-builddep = %{version}-%{release}
Provides:       dnf-plugin-config-manager = %{version}-%{release}
Provides:       dnf-plugin-debuginfo-install = %{version}-%{release}
Provides:       dnf-plugin-download = %{version}-%{release}
Provides:       dnf-plugin-generate_completion_cache = %{version}-%{release}
Provides:       dnf-plugin-groups-manager = %{version}-%{release}
Provides:       dnf-plugin-needs_restarting = %{version}-%{release}
Provides:       dnf-plugin-repoclosure = %{version}-%{release}
Provides:       dnf-plugin-repograph = %{version}-%{release}
Provides:       dnf-plugin-repomanage = %{version}-%{release}
Provides:       dnf-plugin-reposync = %{version}-%{release}

Conflicts:      dnf-plugins-extras-common-data < %{dnf_plugins_extra}

%description
Core Plugins for DNF. This package enhances DNF with the builddep, config-manager,
%{?_with_copr_plugin:copr, }debug, debuginfo-install, download, groups-manager,
needs-restarting, repoclosure, repograph, repomanage, and reposync commands.
Additionally, it provides the generate_completion_cache passive plugin.

%package -n python3-dnf-plugins-core
Summary:        Python 3 interface to core plugins for DNF
Group:          System/Packages
BuildRequires:  python3-Sphinx
BuildRequires:  python3-dbus-python
BuildRequires:  python3-devel
BuildRequires:  python3-dnf >= %{dnf_lowest_compatible}
BuildRequires:  python3-pytest
Requires:       python3-dateutil
Requires:       python3-dbus-python
Requires:       python3-distro
Requires:       python3-dnf >= %{dnf_lowest_compatible}
Requires:       python3-hawkey >= %{hawkey_version}

Conflicts:      %{name} <= 0.1.5
# let the both python plugin versions be updated simultaneously
Conflicts:      python3-%{name} < %{version}-%{release}
Conflicts:      python2-%{name} < %{version}-%{release}
Provides:       python3-dnf-plugins-extras-debug = %{version}-%{release}
Provides:       python3-dnf-plugins-extras-repoclosure = %{version}-%{release}
Provides:       python3-dnf-plugins-extras-repograph = %{version}-%{release}
Provides:       python3-dnf-plugins-extras-repomanage = %{version}-%{release}
Obsoletes:      python3-dnf-plugins-extras-debug < %{dnf_plugins_extra}
Obsoletes:      python3-dnf-plugins-extras-repoclosure < %{dnf_plugins_extra}
Obsoletes:      python3-dnf-plugins-extras-repograph < %{dnf_plugins_extra}
Obsoletes:      python3-dnf-plugins-extras-repomanage < %{dnf_plugins_extra}
# No longer supporting Python 2
Obsoletes:      python2-dnf-plugins-core < 4.0.3

%description -n python3-dnf-plugins-core
Core Plugins for DNF, Python 3 interface. This package enhances DNF with
the builddep, config-manager, %{?_with_copr_plugin:copr, }debug, debuginfo-install,
download, groups-manager, needs-restarting, repoclosure, repograph, repomanage,
and reposync commands.

Additionally, it provides the generate_completion_cache passive plugin.

%package -n %{yum_utils_subpackage_name}
Summary:        Yum-utils CLI compatibility layer
Group:          System/Packages
%if %{with as_yum}
Obsoletes:      dnf-utils < %{version}-%{release}
Obsoletes:      yum-utils < 4.0.0
Provides:       dnf-utils = %{version}-%{release}
# SUSE-specific yum-utils subpackage obsoletion
Obsoletes:      yum-changelog < 4.0.0
Provides:       yum-changelog = %{version}-%{release}
%else
# dnf-utils offers the same binaries as yum-utils
Conflicts:      yum-changelog
Conflicts:      yum-utils
%endif
%if ! %{with deconflict}
# Cf. https://github.com/openSUSE/zypper/pull/254
Conflicts:      zypper < 1.14.26
Conflicts:      zypper-needs-restarting
%endif
Requires:       %{name} = %{version}-%{release}
Requires:       dnf >= %{dnf_lowest_compatible}
Requires:       python3-dnf >= %{dnf_lowest_compatible}

%description -n %{yum_utils_subpackage_name}
As a Yum-utils CLI compatibility layer, supplies in CLI shims for
debuginfo-install, groups-manager, repograph, package-cleanup, repoclosure,
repomanage, repoquery, reposync, repotrack, builddep, config-manager, debug,
and download that use new implementations using DNF.

%package -n python3-dnf-plugin-leaves
Summary:        Leaves Plugin for DNF
Group:          System/Packages
Requires:       python3-%{name} = %{version}-%{release}
Provides:       dnf-plugin-leaves = %{version}-%{release}
Provides:       dnf-plugins-extras-leaves = %{version}-%{release}
Provides:       python3-dnf-plugins-extras-leaves = %{version}-%{release}
Provides:       dnf-command(leaves)
Conflicts:      dnf-plugins-extras-common-data < %{dnf_plugins_extra}
Conflicts:      python2-dnf-plugin-leaves < %{version}-%{release}
Obsoletes:      python3-dnf-plugins-extras-leaves < %{dnf_plugins_extra}
# Python 2 variants are no longer provided
Obsoletes:      python2-dnf-plugin-leaves < 4.0.3

%description -n python3-dnf-plugin-leaves
Leaves Plugin for DNF, Python 3 version. List all installed packages
not required by any other installed package.

%package -n python3-dnf-plugin-local
Summary:        Local Plugin for DNF
Group:          System/Packages
Requires:       createrepo_c
Requires:       python3-%{name} = %{version}-%{release}
Provides:       dnf-plugin-local =  %{version}-%{release}
Provides:       dnf-plugins-extras-local = %{version}-%{release}
Provides:       python3-dnf-plugins-extras-local = %{version}-%{release}
Conflicts:      dnf-plugins-extras-common-data < %{dnf_plugins_extra}
Conflicts:      python2-dnf-plugin-local < %{version}-%{release}
Obsoletes:      python3-dnf-plugins-extras-local < %{dnf_plugins_extra}
# Python 2 variants are no longer provided
Obsoletes:      python2-dnf-plugin-local < 4.0.3

%description -n python3-dnf-plugin-local
Local Plugin for DNF, Python 3 version. Automatically copy all downloaded
packages to a repository on the local filesystem and generating repo metadata.

%package -n python3-dnf-plugin-post-transaction-actions
Summary:        Post transaction actions Plugin for DNF
Group:          System/Packages
Requires:       python3-%{name} = %{version}-%{release}
Provides:       dnf-plugin-post-transaction-actions =  %{version}-%{release}
Conflicts:      python2-dnf-plugin-post-transaction-actions < %{version}-%{release}

%description -n python3-dnf-plugin-post-transaction-actions
Post transaction actions Plugin for DNF, Python 3 version. Plugin runs actions
(shell commands) after transaction is completed. Actions are defined in action
files.

%package -n python3-dnf-plugin-show-leaves
Summary:        Show-leaves Plugin for DNF
Group:          System/Packages
Requires:       python3-%{name} = %{version}-%{release}
Requires:       python3-dnf-plugin-leaves = %{version}-%{release}
Provides:       dnf-plugin-show-leaves =  %{version}-%{release}
Provides:       dnf-plugins-extras-show-leaves = %{version}-%{release}
Provides:       python3-dnf-plugins-extras-show-leaves = %{version}-%{release}
Provides:       dnf-command(show-leaves)
Conflicts:      dnf-plugins-extras-common-data < %{dnf_plugins_extra}
Conflicts:      python2-dnf-plugin-show-leaves < %{version}-%{release}
Obsoletes:      python3-dnf-plugins-extras-show-leaves < %{dnf_plugins_extra}
# Python 2 variants are no longer provided
Obsoletes:      python2-dnf-plugin-show-leaves < 4.0.3

%description -n python3-dnf-plugin-show-leaves
Show-leaves Plugin for DNF, Python 3 version. List all installed
packages that are no longer required by any other installed package
after a transaction.

%package -n python3-dnf-plugin-versionlock
Summary:        Version Lock Plugin for DNF
Group:          System/Packages
Requires:       python3-%{name} = %{version}-%{release}
Provides:       dnf-plugin-versionlock =  %{version}-%{release}
Provides:       dnf-plugins-extras-versionlock = %{version}-%{release}
Provides:       python3-dnf-plugins-extras-versionlock = %{version}-%{release}
Provides:       dnf-command(versionlock)
Conflicts:      dnf-plugins-extras-common-data < %{dnf_plugins_extra}
Conflicts:      python2-dnf-plugin-versionlock < %{version}-%{release}
Obsoletes:      python3-dnf-plugins-extras-versionlock < %{dnf_plugins_extra}
# Python 2 variants are no longer provided
Obsoletes:      python2-dnf-plugin-versionlock < 4.0.3
%if %{with as_yum}
# SUSE-specific yum-utils subpackage obsoletion
Obsoletes:      yum-versionlock < 4.0.0
Provides:       yum-versionlock = %{version}-%{release}
%endif

%description -n python3-dnf-plugin-versionlock
Version lock plugin takes a set of name/versions for packages and excludes all other
versions of those packages. This allows you to e.g. protect packages from being
updated by newer versions.

%package -n python3-dnf-plugin-modulesync
Summary:        Download module metadata and packages and create repository
Group:          System/Packages
Requires:       createrepo_c >= 0.17.4
Requires:       python3-%{name} = %{version}-%{release}
Provides:       dnf-plugin-modulesync = %{version}-%{release}
Provides:       dnf-command(modulesync)

%description -n python3-dnf-plugin-modulesync
Download module metadata from all enabled repositories, module artifacts,
and profiles of matching modules and create repository.


%lang_package

%prep
%autosetup -p1

# openSUSE installs libexec content into /usr/lib...
sed -e "s:libexec:%{_libexecdir}:g" -i libexec/CMakeLists.txt

# Fix sphinx-build run...
sed -e "s/sphinx-build-3/sphinx-build-%{python3_version}/" -i doc/CMakeLists.txt

%build
%cmake -DPYTHON_DESIRED:FILEPATH=%{__python3}
%make_build
make doc-man

%install
pushd ./build
%make_install
popd

%find_lang %{name}

# For directory ownership?
mkdir -p %{buildroot}%{_var}/cache/dnf

mv %{buildroot}%{_libexecdir}/dnf-utils-3 %{buildroot}%{_libexecdir}/dnf-utils
rm -vf %{buildroot}%{_libexecdir}/dnf-utils-*

mkdir -p %{buildroot}%{_bindir}
ln -sf %{_libexecdir}/dnf-utils %{buildroot}%{_bindir}/debuginfo-install
ln -sf %{_libexecdir}/dnf-utils %{buildroot}%{_bindir}/needs-restarting
ln -sf %{_libexecdir}/dnf-utils %{buildroot}%{_bindir}/find-repos-of-install
ln -sf %{_libexecdir}/dnf-utils %{buildroot}%{_bindir}/repo-graph
ln -sf %{_libexecdir}/dnf-utils %{buildroot}%{_bindir}/package-cleanup
ln -sf %{_libexecdir}/dnf-utils %{buildroot}%{_bindir}/repoclosure
ln -sf %{_libexecdir}/dnf-utils %{buildroot}%{_bindir}/repodiff
ln -sf %{_libexecdir}/dnf-utils %{buildroot}%{_bindir}/repomanage
ln -sf %{_libexecdir}/dnf-utils %{buildroot}%{_bindir}/repoquery
ln -sf %{_libexecdir}/dnf-utils %{buildroot}%{_bindir}/reposync
ln -sf %{_libexecdir}/dnf-utils %{buildroot}%{_bindir}/repotrack
ln -sf %{_libexecdir}/dnf-utils %{buildroot}%{_bindir}/yum-builddep
ln -sf %{_libexecdir}/dnf-utils %{buildroot}%{_bindir}/yum-config-manager
ln -sf %{_libexecdir}/dnf-utils %{buildroot}%{_bindir}/yum-debug-dump
ln -sf %{_libexecdir}/dnf-utils %{buildroot}%{_bindir}/yum-debug-restore
ln -sf %{_libexecdir}/dnf-utils %{buildroot}%{_bindir}/yum-groups-manager
ln -sf %{_libexecdir}/dnf-utils %{buildroot}%{_bindir}/yumdownloader

%if %{with deconflict}
# Deal with conflicts to unblock backports
mv %{buildroot}%{_bindir}/needs-restarting %{buildroot}%{_bindir}/dnfutils-needs-restarting
mv %{buildroot}%{_mandir}/man1/needs-restarting.1 %{buildroot}%{_mandir}/man1/dnfutils-needs-restarting.1
%endif

%if ! %{with copr_plugin}
# Delete if we're not shipping COPR plugin
rm -rf %{buildroot}%{_sysconfdir}/dnf/plugins/copr.d
rm -rf %{buildroot}%{_sysconfdir}/dnf/plugins/copr.conf
%endif

%python_compileall
%fdupes %{buildroot}%{python3_sitelib}

%if %{with tests}
%check
export PYTHONDONTWRITEBYTECODE=1
export PYTHONPATH=./plugins
/usr/bin/pytest-%{python3_version} -v -s tests/
%endif

%files
%license COPYING
%doc AUTHORS README.rst
%{_mandir}/man8/dnf-builddep.*
%{_mandir}/man8/dnf-changelog.*
%{_mandir}/man8/dnf-config-manager.*
%if %{with copr_plugin}
%{_mandir}/man8/dnf-copr.*
%config(noreplace) %{_sysconfdir}/dnf/plugins/copr.conf
%dir %{_sysconfdir}/dnf/plugins/copr.d
%else
%exclude %{_mandir}/man8/dnf-copr.*
%endif
%{_mandir}/man8/dnf-debug.*
%{_mandir}/man8/dnf-debuginfo-install.*
%{_mandir}/man8/dnf-download.*
%{_mandir}/man8/dnf-generate_completion_cache.*
%{_mandir}/man8/dnf-groups-manager.*
%{_mandir}/man8/dnf-needs-restarting.*
%{_mandir}/man8/dnf-repoclosure.*
%{_mandir}/man8/dnf-repograph.*
%{_mandir}/man8/dnf-repomanage.*
%{_mandir}/man8/dnf-reposync.*
%{_mandir}/man8/dnf-repodiff.*
%dir %{_sysconfdir}/dnf/protected.d
%dir %{_var}/cache/dnf
%ghost %{_var}/cache/dnf/packages.db
%config(noreplace) %{_sysconfdir}/dnf/plugins/debuginfo-install.conf

%files lang -f %{name}.lang

%files -n python3-dnf-plugins-core
%license COPYING
%doc AUTHORS README.rst
%dir %{python3_sitelib}/dnf-plugins/__pycache__
%{python3_sitelib}/dnf-plugins/builddep.py
%{python3_sitelib}/dnf-plugins/__pycache__/builddep.*
%{python3_sitelib}/dnf-plugins/changelog.py
%{python3_sitelib}/dnf-plugins/__pycache__/changelog.*
%{python3_sitelib}/dnf-plugins/config_manager.py
%{python3_sitelib}/dnf-plugins/__pycache__/config_manager.*
%if %{with copr_plugin}
%{python3_sitelib}/dnf-plugins/copr.py
%{python3_sitelib}/dnf-plugins/__pycache__/copr.*
%else
%exclude %{python3_sitelib}/dnf-plugins/copr.*
%{python3_sitelib}/dnf-plugins/__pycache__/copr.*
%endif
%{python3_sitelib}/dnf-plugins/debug.py
%{python3_sitelib}/dnf-plugins/__pycache__/debug.*
%{python3_sitelib}/dnf-plugins/debuginfo-install.py
%{python3_sitelib}/dnf-plugins/__pycache__/debuginfo-install.*
%{python3_sitelib}/dnf-plugins/download.py
%{python3_sitelib}/dnf-plugins/__pycache__/download.*
%{python3_sitelib}/dnf-plugins/generate_completion_cache.py
%{python3_sitelib}/dnf-plugins/__pycache__/generate_completion_cache.*
%{python3_sitelib}/dnf-plugins/groups_manager.py
%{python3_sitelib}/dnf-plugins/__pycache__/groups_manager.*
%{python3_sitelib}/dnf-plugins/needs_restarting.py
%{python3_sitelib}/dnf-plugins/__pycache__/needs_restarting.*
%{python3_sitelib}/dnf-plugins/repoclosure.py
%{python3_sitelib}/dnf-plugins/__pycache__/repoclosure.*
%{python3_sitelib}/dnf-plugins/repograph.py
%{python3_sitelib}/dnf-plugins/__pycache__/repograph.*
%{python3_sitelib}/dnf-plugins/repomanage.py
%{python3_sitelib}/dnf-plugins/__pycache__/repomanage.*
%{python3_sitelib}/dnf-plugins/reposync.py
%{python3_sitelib}/dnf-plugins/__pycache__/reposync.*
%{python3_sitelib}/dnf-plugins/repodiff.py
%{python3_sitelib}/dnf-plugins/__pycache__/repodiff.*
%{python3_sitelib}/dnfpluginscore/

%files -n %{yum_utils_subpackage_name}
%{_libexecdir}/dnf-utils
%{_mandir}/man1/dnf-utils.1*
%{_bindir}/debuginfo-install
%{_mandir}/man1/debuginfo-install.1*
%{_bindir}/%{?deconflict_prefix}needs-restarting
%{_mandir}/man1/%{?deconflict_prefix}needs-restarting.1*
%{_bindir}/find-repos-of-install
%{_bindir}/package-cleanup
%{_mandir}/man1/package-cleanup.1*
%{_bindir}/repo-graph
%{_mandir}/man1/repo-graph.1*
%{_bindir}/repoclosure
%{_mandir}/man1/repoclosure.1*
%{_bindir}/repodiff
%{_mandir}/man1/repodiff.1*
%{_bindir}/repomanage
%{_mandir}/man1/repomanage.1*
%{_bindir}/repoquery
%{_bindir}/reposync
%{_mandir}/man1/reposync.1*
%{_bindir}/repotrack
%{_bindir}/yum-builddep
%{_mandir}/man1/yum-builddep.1*
%{_bindir}/yum-config-manager
%{_mandir}/man1/yum-config-manager.1*
%{_bindir}/yum-debug-dump
%{_mandir}/man1/yum-debug-dump.1*
%{_bindir}/yum-debug-restore
%{_mandir}/man1/yum-debug-restore.1*
%{_bindir}/yum-groups-manager
%{_mandir}/man1/yum-groups-manager.1*
%{_bindir}/yumdownloader
%{_mandir}/man1/yumdownloader.1*
%{_mandir}/man1/yum-changelog.1*
%{_mandir}/man1/yum-utils.1*
%{_mandir}/man5/yum-versionlock.conf.5*
%{_mandir}/man8/yum-copr.8*
%{_mandir}/man8/yum-versionlock.8*

%files -n python3-dnf-plugin-leaves
%dir %{python3_sitelib}/dnf-plugins/__pycache__
%{python3_sitelib}/dnf-plugins/leaves.*
%{python3_sitelib}/dnf-plugins/__pycache__/leaves.*
%{_mandir}/man8/dnf-leaves.*

%files -n python3-dnf-plugin-local
%config(noreplace) %{_sysconfdir}/dnf/plugins/local.conf
%dir %{python3_sitelib}/dnf-plugins/__pycache__
%{python3_sitelib}/dnf-plugins/local.*
%{python3_sitelib}/dnf-plugins/__pycache__/local.*
%{_mandir}/man8/dnf-local.*

%files -n python3-dnf-plugin-post-transaction-actions
%config(noreplace) %{_sysconfdir}/dnf/plugins/post-transaction-actions.conf
%dir %{_sysconfdir}/dnf/plugins/post-transaction-actions.d
%dir %{python3_sitelib}/dnf-plugins/__pycache__
%{python3_sitelib}/dnf-plugins/post-transaction-actions.*
%{python3_sitelib}/dnf-plugins/__pycache__/post-transaction-actions.*
%{_mandir}/man8/dnf-post-transaction-actions.*

%files -n python3-dnf-plugin-show-leaves
%dir %{python3_sitelib}/dnf-plugins/__pycache__
%{python3_sitelib}/dnf-plugins/show_leaves.*
%{python3_sitelib}/dnf-plugins/__pycache__/show_leaves.*
%{_mandir}/man8/dnf-show-leaves.*

%files -n python3-dnf-plugin-versionlock
%config(noreplace) %{_sysconfdir}/dnf/plugins/versionlock.conf
%config(noreplace) %{_sysconfdir}/dnf/plugins/versionlock.list
%dir %{python3_sitelib}/dnf-plugins/__pycache__
%{python3_sitelib}/dnf-plugins/versionlock.*
%{python3_sitelib}/dnf-plugins/__pycache__/versionlock.*
%{_mandir}/man8/dnf-versionlock.*

%files -n python3-dnf-plugin-modulesync
%dir %{python3_sitelib}/dnf-plugins/__pycache__
%{python3_sitelib}/dnf-plugins/modulesync.*
%{python3_sitelib}/dnf-plugins/__pycache__/modulesync.*
%{_mandir}/man8/dnf-modulesync.*

%changelog
* Fri Feb 24 2023 Bruno Pitrus <brunopitrus@hotmail.com>
- Precompile python bytecode (boo#1208151)
* Sat Oct 15 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 4.3.1
  * Update translations
- includes changes from 4.3.0:
  * [repomanage] Modules are used only when they belong to target repo
  * copr: Guess EPEL chroots for CentOS Stream
  * builddep: Warning when using macros with source rpms
  * Update documentation for config-manager used with subscription-manager
  * Update translations
- includes changes from 4.2.1
  * Skip all non rpm tsi for transaction_action plugins
- includes changes from 4.2.0
  * repomanage: Add new option --oldonly
* Sun Mar 27 2022 Neal Gompa <ngompa13@gmail.com>
- Update to 4.1.0
  + Add a new subpackage with modulesync command. The command downloads
    packages from modules and/or creates a repository with modular data. (rh#1868047)
  + [groups-manager] Use full NEVRA (not only name) for matching packages (rh#2013633)
  + [repoclosure] Print counts of missing dependencies
  + [reposync] Do not stop downloading packages on the first error (rh#2009894)
  + [versionlock] Fix: Multiple package-name-spec arguments don't lock correctly (rh#2001039) (rh#2013324)
  + [versionlock] Update documentation for adding specifi version (rh#2013332)
* Wed Nov  3 2021 Neal Gompa <ngompa13@gmail.com>
- Update to 4.0.24
  + [copr] Avoid using deprecated function distro.linux_distribution() (rh#2011550)
  + [copr] don't traceback on empty lines in /etc/os-release
  + [leaves] Show strongly connected components
  + [needs-restarting] Fix wrong boot time (rh#1960437)
  + [playground] Disable playground command, since it doesn't work
* Fri Aug 27 2021 Neal Gompa <ngompa13@gmail.com>
- Update to 4.0.22
  + [repomanage] Allow running only with metadata
  + [repomanage] Enhance documentation (rh#1898293)
  + [versionlock] Locking obsoleted package does not make the obsoleter unavailable (rh#1957280)
  + [versionlock] Work correctly with packages with minorbump part of release (rh#1961217)
* Tue Apr 13 2021 Neal Gompa <ngompa13@gmail.com>
- Update to version 4.0.21
  + Add missing command line option to documentation
  + doc: add packages to needs-restarting conf
  + Set blacklist subcommand as deprecated
  + Bugs fixed (rh#1914827, rh#1916782)
  + Removed dependency on dnf.yum.misc.Checksum class (rh#1935465)
* Wed Feb  3 2021 Neal Gompa <ngompa13@gmail.com>
- Update to version 4.0.19
  + copr: allow only 2 arguments with copr enable command
  + [needs-restarting] fix -r in nspawn containers (rh#1913962, rh#1914251)
  + Add --gpgcheck option to reposync (rh#1856818) (rh#1856818)
  + Re-introduce yum-groups-manager functionality (rh#1826016)
  + [repomanage] Don't use cached metadata (rh#1899852)
  + [needs-restarting] add -s to list services (rh#1772939) (rh#1772939)
* Sat Oct 24 2020 Neal Gompa <ngompa13@gmail.com>
- Update to version 4.0.18
  + [needs-restarting] Fix plugin fail if needs-restarting.d does not exist
  + [needs-restarting] add kernel-rt to reboot list
  + Fix debug-restore command
  + [config-manager] enable/disable comma separated pkgs (rh#1830530)
  + [debug] Use standard demands.resolving for transaction handling
  + [debug] Do not remove install-only packages (rh#1844533)
  + return error when dnf download failed
  + [reposync] Add latest NEVRAs per stream to download (rh#1833074)
  + copr: don't try to list runtime dependencies
* Tue Jul  7 2020 Neal Gompa <ngompa13@gmail.com>
- Update to version 4.0.17
  + Support remote files in dnf builddep
  + [download] Respect repo priority (rh#1800342)
  + [versionlock] Take obsoletes into account (rh#1627124)
  + Move args "--set-enabled", "--set-disabled" from DNF (rh#1727882)
  + Add missing arguments --set-enabled/--set-diabled into error message
  + Warn when --enablerepo/--disablerepo args were passed (rh#1727882)
  + [copr] add support for enabling/disabling runtime dependencies
  + [copr] no-liability text to be always printed
  + [repomanage] Add modular support (rh#1804720)
  + [needs-restarting] add options using .conf file (rh#1810123)
- Fix author identity in changes
* Fri Jul  3 2020 Petr Gajdos <pgajdos@suse.com>
- test package and test it with pytest (drop dependency on nose)
* Thu Feb 27 2020 Neal Gompa <ngompa13@gmail.com>
- Update to version 4.0.14
  + Fix conflict for dnf download --resolve (rh#1787908)
  + config-manager calls parser error when without options (rh#1782822)
  + Update reposync.py with --norepopath option
  + Fix: don't open stdin if versionlock is missing (rh#1785563)
* Sun Jan 19 2020 Neal Gompa <ngompa13@gmail.com>
- Update to version 4.0.13
  + Fix: config_manager respect config file location during save
  + Redesign reposync --latest for modular system (rh#1775434)
  + [reposync] Fix --delete with multiple repos (rh#1774103)
  + [doc] Skip creating and installing migrate documentation for Python 3+
  + [config-manager] Allow use of --set-enabled without arguments (rh#1679213)
  + [versionlock] Prevent conflicting/duplicate entries (rh#1782052)
- Deconflict with zypper-needs-restarting on SLE to unblock PackageHub updates
* Sat Dec 14 2019 Neal Gompa <ngompa13@gmail.com>
- Add missing bug reference for 4.0.7 update changelog entry
* Sun Dec  1 2019 Neal Gompa <ngompa13@gmail.com>
- Update to version 4.0.12
  + [reposync] Enable timestamp preserving for downloaded data (rh#1688537)
  + [reposync] Download packages from all streams (rh#1714788)
  + Make yum-copr manpage available (rh#1673902)
  + [needs-restarting] Add ``--reboothint`` option (rh#1192946) (rh#1639468)
  + Set the cost of ``_dnf_local`` repo to 500, to make it preferred to normal repos
  + [builddep] Report all rpm errors (rh#1663619, rh#1658292, rh#1724668)
  + [config-manager] --setopt: Fix crash with "--save --dump"
  + [config-manager] --setopt: Add globs support to repoid
  + [config-manager] --setopt=key=value is applied only to the main config
  + [config-manager] --setopt and empty list of repositories (rh#1702678)
  + [config-manager] --setopt: Add check for existence of input repositories
  + debuginfo-install: Update both debuginfo and debugsource for updated package (rh#1586084)
  + copr: Support multilib repofiles (rh#1393664)
  + copr: Fix disable if copr instance has non-default port
  + copr: Fix repoid when using subdirectories in copr project
  + [spec] Specify attributes for ghost file (rh# 1754463)
  + download: add the --debugsource option (rh#1637008)
  + Fix incorrect handling richdeps in buildep (rh#1756902)
  + [reposync] Add --urls option (rh#1686602)
  + [versionlock] Add --raw option (rh#1645564)
  + [doc] move manpages for plugins to "dnf-PLUGIN" (rh#1706386)
  + Add new plugin post-transaction-actions (rh#967264)
  + [builddep] Add --skip-unavailable switch (rh#1628634)
  + [versionlock] Don't apply excludes on @System (rh#1726712)
  + [reposync] Ignore only modular excludes (rh#1750273)
- Rename dnf-utils package to yum-utils and have it replace removed package in Tumbleweed
* Fri May 24 2019 Neal Gompa <ngompa13@gmail.com>
- Update to version 4.0.7
  + Fix: copr disable command traceback (rh#1693551)
  + [doc] state repoid as repo identifier of config-manager (rh#1686779)
  + Fix download of src when not the latest requested (rh#1649627)
- Add missing dependencies on dateutil and distro Python modules (boo#1141374)
- Drop backported fixes that are part of this release
  * 0001-Fix-copr-disable-command-traceback-RhBug-1693551.patch
  * 0002-doc-state-repoid-as-repo-identifier-of-config-manage.patch
* Fri Apr 26 2019 Neal Gompa <ngompa13@gmail.com>
- Backport fix for copr disable command traceback (rh#1693551)
  * Patch: 0001-Fix-copr-disable-command-traceback-RhBug-1693551.patch
- Backport doc fix to state repoid as repo identifier for config-manager (rh#1686779)
  * Patch: 0002-doc-state-repoid-as-repo-identifier-of-config-manage.patch
* Sun Mar 31 2019 Neal Gompa <ngompa13@gmail.com>
- Update to version 4.0.6
  + [download] Do not download src without ``--source`` (rh#1666648)
  + Use improved config parser that preserves order of data
  + [leaves] Show multiply satisfied dependencies as leaves
  + [download] Fix downloading an rpm from a URL (rh#1678582)
  + [download] Fix problem with downloading src pkgs (rh#1649627)
- Drop backported fixes that are part of this release
  * 0001-Fix-traceback-when-local-rpm-url-is-passed.patch
  * 0002-reposync-fix-up-path-traversal-prevention.patch
  * 0003-doc-Use-the-correct-sphinx-build-binary-for-Python-2.patch
- Restore needs-restarting files to the dnf-utils package
- Add conflicts to zypper < 1.14.26 to dnf-utils package to prevent file conflicts
* Mon Feb 11 2019 Neal Gompa <ngompa13@gmail.com>
- Temporarily drop needs-restarting files from dnf-utils until
  zypper splits them out into zypper-needs-restarting subpackage
  (gh#openSUSE/zypper#254)
- Add conflicts to yum-changelog and zypper-needs-restarting to
  dnf-utils
* Thu Feb  7 2019 Neal Gompa <ngompa13@gmail.com>
- Rebase to version 4.0.3:
  + Compatible with DNF 4.0.0+
  + Reworked COPR plugin
  + New changelogs and repodiff plugins/subcommands
- Drop Python 2 subpackages
- Drop unneeded patches:
  * 0001-copr-Add-openSUSE-support.patch
  * dnf-plugins-core-2.1.5-Fix-detection-of-Python-2.patch
- Backport fixes from upstream to build and run plugins
  * 0001-Fix-traceback-when-local-rpm-url-is-passed.patch
  * 0002-reposync-fix-up-path-traversal-prevention.patch
  * 0003-doc-Use-the-correct-sphinx-build-binary-for-Python-2.patch
* Mon Apr 23 2018 ngompa13@gmail.com
- Enable COPR plugin with openSUSE support backported (rh#1570418)
  * Add patch: 0001-copr-Add-openSUSE-support.patch
* Sat Jan 20 2018 ngompa13@gmail.com
- Fix build-time detection of Python 2
  * Add patch: dnf-plugins-core-2.1.5-Fix-detection-of-Python-2.patch
* Tue Oct 10 2017 ngompa13@gmail.com
- Update to version 2.1.5:
  + Fix issues with the '--arch' in 'dnf download' (rh#1476834)
  + Fix 'dnf repoclosure' when used with '--check' and '--best'
  + Use preconfigure hook from DNF for 'local' plugin
- Split lang data into lang subpackage
* Sun Aug 13 2017 ngompa13@gmail.com
- Initial package based on Mageia package
